@@ -13,7 +13,8 @@ __author__ = ["Luke Chang"]
 __license__ = "MIT"
 
 from nilearn.signal import clean
-from scipy.stats import ttest_1samp, pearsonr
+from scipy.stats import ttest_1samp, pearsonr, spearmanr
+from scipy.spatial.distance import cdist
 from scipy.stats import t as t_dist
 from scipy.signal import detrend
 from scipy.interpolate import pchip
@@ -33,7 +34,7 @@ from pynv import Client
 from joblib import Parallel, delayed
 from nltools.mask import expand_mask
 from nltools.analysis import Roc
-from nilearn.input_data import NiftiMasker
+from nilearn.maskers import NiftiMasker
 from nilearn.plotting import plot_stat_map
 from nilearn.image import smooth_img, resample_to_img
 from nilearn.masking import intersect_masks
@@ -71,6 +72,7 @@ from nltools.prefs import MNI_Template, resolve_mni_path
 from nilearn.decoding import SearchLight
 import deepdish as dd
 from pathlib import Path
+import warnings
 
 
 # Optional dependencies
@@ -90,15 +92,12 @@ class Brain_Data(object):
         Y: Pandas DataFrame of training labels
         X: Pandas DataFrame Design Matrix for running univariate models
         mask: binary nifiti file to mask brain data
-        output_file: Name to write out to nifti file
         **kwargs: Additional keyword arguments to pass to the prediction
                 algorithm
 
     """
 
-    def __init__(
-        self, data=None, Y=None, X=None, mask=None, output_file=None, **kwargs
-    ):
+    def __init__(self, data=None, Y=None, X=None, mask=None, **kwargs):
         if mask is not None:
             if not isinstance(mask, nib.Nifti1Image):
                 if isinstance(mask, str) or isinstance(mask, Path):
@@ -112,8 +111,10 @@ class Brain_Data(object):
                     )
             self.mask = mask
         else:
+            # Load default mask
             self.mask = nib.load(resolve_mni_path(MNI_Template)["mask"])
-        self.nifti_masker = NiftiMasker(mask_img=self.mask)
+        # Learn transformation on mask
+        self.nifti_masker = NiftiMasker(mask_img=self.mask, **kwargs)
 
         if data is not None:
             if isinstance(data, str) or isinstance(data, Path):
@@ -150,25 +151,36 @@ class Brain_Data(object):
                             for e in f["Y_index"]
                         ],
                     )
-                    self.mask = nib.Nifti1Image(
-                        f["mask_data"],
-                        affine=f["mask_affine"],
-                        file_map={
-                            "image": nib.FileHolder(filename=f["mask_file_name"])
-                        },
-                    )
-                    nifti_masker = NiftiMasker(self.mask)
-                    self.nifti_masker = nifti_masker.fit(self.mask)
-                    self.file_name = f["file_name"]
+                    if mask is None:
+                        # User didn't request a mask so try to load it from the h5 file,
+                        # i.e. overwrite the default mask loaded above
+                        self.mask = nib.Nifti1Image(
+                            f["mask_data"],
+                            affine=f["mask_affine"],
+                            file_map={
+                                "image": nib.FileHolder(filename=f["mask_file_name"])
+                            },
+                        )
+                        nifti_masker = NiftiMasker(self.mask)
+                        self.nifti_masker = nifti_masker.fit(self.mask)
+                    else:
+                        # Mask is already set above so use the default or user requested
+                        # mask rather than the one in h5 (if it exists)
+                        if "mask_data" in f:
+                            warnings.warn(
+                                "Existing mask found in HDF5 file but is being ignored because you passed a value for mask. Set mask=None to use existing mask in the HDF5 file"
+                            )
+                    # We're done initializing from the h5 file so just return no need to
+                    # run any of the additional checks and code below. We should really
+                    # refactor this entire init...
                     return
-
                 else:
                     data = nib.load(data)
                 self.data = self.nifti_masker.fit_transform(data)
             elif isinstance(data, list):
                 if isinstance(data[0], Brain_Data):
                     tmp = concatenate(data)
-                    for item in ["data", "Y", "X", "mask", "nifti_masker", "file_name"]:
+                    for item in ["data", "Y", "X", "mask", "nifti_masker"]:
                         setattr(self, item, getattr(tmp, item))
                 else:
                     if all(isinstance(x, data[0].__class__) for x in data):
@@ -222,17 +234,14 @@ class Brain_Data(object):
         else:
             self.X = pd.DataFrame()
 
-        self.file_name = output_file if output_file is not None else []
-
     def __repr__(self):
-        return "%s.%s(data=%s, Y=%s, X=%s, mask=%s, output_file=%s)" % (
+        return "%s.%s(data=%s, Y=%s, X=%s, mask=%s)" % (
             self.__class__.__module__,
             self.__class__.__name__,
             self.shape(),
             len(self.Y),
             self.X.shape,
             os.path.basename(self.mask.get_filename()),
-            self.file_name,
         )
 
     def __getitem__(self, index):
@@ -479,7 +488,7 @@ class Brain_Data(object):
 
         return self.nifti_masker.inverse_transform(self.data)
 
-    def write(self, file_name=None, **kwargs):
+    def write(self, file_name, **kwargs):
         """Write out Brain_Data object to Nifti or HDF5 File.
 
         Args:
@@ -504,7 +513,6 @@ class Brain_Data(object):
                     "mask_affine": self.mask.affine,
                     "mask_data": self.mask.get_fdata(),
                     "mask_file_name": self.mask.get_filename(),
-                    "file_name": self.file_name,
                 },
                 compression=kwargs.get("compression", "blosc"),
             )
@@ -544,7 +552,7 @@ class Brain_Data(object):
         threshold_lower=None,
         figsize=(15, 2),
         axes=None,
-        **kwargs
+        **kwargs,
     ):
         """Create a quick plot of self.data.  Will plot each image separately
 
@@ -589,7 +597,7 @@ class Brain_Data(object):
                     colorbar=colorbar,
                     draw_cross=draw_cross,
                     axes=axes,
-                    **kwargs
+                    **kwargs,
                 )
             else:
                 if axes is not None:
@@ -608,7 +616,7 @@ class Brain_Data(object):
                         colorbar=colorbar,
                         draw_cross=draw_cross,
                         axes=a[i],
-                        **kwargs
+                        **kwargs,
                     )
             return
         elif view in ["glass", "mni", "full"]:
@@ -618,7 +626,7 @@ class Brain_Data(object):
                     how=view,
                     thr_upper=threshold_upper,
                     thr_lower=threshold_lower,
-                    **kwargs
+                    **kwargs,
                 )
             else:
                 raise ValueError(
@@ -685,7 +693,7 @@ class Brain_Data(object):
         if self.data.shape[0] != self.X.shape[0]:
             raise ValueError("self.X does not match the correct size of " "self.data")
 
-        b, t, p, _, res = regression(self.X, self.data, mode=mode, **kwargs)
+        b, se, t, p, df, res = regression(self.X, self.data, mode=mode, **kwargs)
 
         # Prevent copy of all data in self multiple times; instead start with an empty instance and copy only needed attributes from self, and use this as a template for other outputs
         b_out = self.__class__()
@@ -693,15 +701,24 @@ class Brain_Data(object):
         b_out.nifti_masker = deepcopy(self.nifti_masker)
 
         # Use this as template for other outputs before setting data
+        se_out = b_out.copy()
         t_out = b_out.copy()
         p_out = b_out.copy()
-        sigma_out = b_out.copy()
+        df_out = b_out.copy()
         res_out = b_out.copy()
-        b_out.data, t_out.data, p_out.data, sigma_out.data, res_out.data = (
+        (
+            b_out.data,
+            se_out.data,
+            t_out.data,
+            p_out.data,
+            df_out.data,
+            res_out.data,
+        ) = (
             b,
+            se,
             t,
             p,
-            sigma_out,
+            df,
             res,
         )
 
@@ -709,7 +726,8 @@ class Brain_Data(object):
             "beta": b_out,
             "t": t_out,
             "p": p_out,
-            "sigma": sigma_out,
+            "df": df_out,
+            "sigma": se_out,
             "residual": res_out,
         }
 
@@ -905,6 +923,17 @@ class Brain_Data(object):
 
         """
 
+        supported_metrics = [
+            "correlation",
+            "pearson",
+            "rank_correlation",
+            "spearman",
+            "dot_product",
+            "cosine",
+        ]
+        if method not in supported_metrics:
+            raise ValueError(f"method must be one of {supported_metrics}")
+
         image = check_brain_data(image)
 
         # Check to make sure masks are the same for each dataset and if not
@@ -925,59 +954,20 @@ class Brain_Data(object):
             data2 = self.data
             image2 = image.data
 
-        def vector2array(data):
-            if len(data.shape) == 1:
-                return data.reshape(-1, 1).T
-            else:
-                return data
-
-        def flatten_array(data):
-            if np.any(np.array(data.shape) == 1):
-                data = data.flatten()
-                if len(data) == 1 & data.shape[0] == 1:
-                    data = data[0]
-            return data
-
-        # Calculate pattern expression
         if method == "dot_product":
-            if len(image2.shape) > 1:
-                if image2.shape[0] > 1:
-                    pexp = []
-                    for i in range(image2.shape[0]):
-                        pexp.append(np.dot(data2, image2[i, :]))
-                    pexp = np.array(pexp)
-                else:
-                    pexp = np.dot(data2, image2)
-            else:
-                pexp = np.dot(data2, image2)
-        elif method == "correlation":
-            if len(image2.shape) > 1:
-                if image2.shape[0] > 1:
-                    pexp = []
-                    for i in range(image2.shape[0]):
-                        pexp.append(pearson(image2[i, :], data2))
-                    pexp = np.array(pexp)
-                else:
-                    pexp = pearson(image2, data2)
-            else:
-                pexp = pearson(image2, data2)
+            func = lambda x, y: np.dot(x, y)
+        elif method in ["pearson", "correlation"]:
+            func = lambda x, y: pearsonr(x, y)[0]
+        elif method in ["spearman", "rank_correlation"]:
+            func = lambda x, y: spearmanr(x, y)[0]
         elif method == "cosine":
-            image2 = vector2array(image2)
-            data2 = vector2array(data2)
-            if image2.shape[1] > 1:
-                pexp = []
-                for i in range(image2.shape[0]):
-                    pexp.append(
-                        cosine_similarity(
-                            image2[i, :].reshape(-1, 1).T, data2
-                        ).flatten()
-                    )
-                pexp = np.array(pexp)
-            else:
-                pexp = cosine_similarity(image2, data2).flatten()
-        else:
-            raise ValueError("Method must be one of: correlation, dot_product, cosine")
-        return flatten_array(pexp)
+            func = method
+
+        out = cdist(np.atleast_2d(data2), np.atleast_2d(image2), func).squeeze()
+        # cdist metric argument returns distances by default (unless we specific a
+        # custom function like above) so flip it to similarity
+        out = 1 - out if method == "cosine" else out
+        return out
 
     def distance(self, metric="euclidean", **kwargs):
         """Calculate distance between images within a Brain_Data() instance.
@@ -1335,7 +1325,7 @@ class Brain_Data(object):
         scoring=None,
         n_jobs=1,
         verbose=0,
-        **kwargs
+        **kwargs,
     ):
         """Perform multi-region prediction. This can be a searchlight analysis or multi-roi analysis if provided a Brain_Data instance with labeled non-overlapping rois.
 
@@ -1598,7 +1588,7 @@ class Brain_Data(object):
             np.dot(np.dot(X, np.linalg.pinv(np.dot(X.T, X))), X.T), Y.flatten("F")
         )
         residuals = Y.flatten("F") - predicted_Y
-        SSE = (residuals ** 2).sum()
+        SSE = (residuals**2).sum()
 
         MSE = SSE / dfe
 
@@ -1661,7 +1651,7 @@ class Brain_Data(object):
         collection_id=None,
         img_type=None,
         img_modality=None,
-        **kwargs
+        **kwargs,
     ):
         """Upload Data to Neurovault.  Will add any columns in self.X to image
             metadata. Index will be used as image name.
@@ -1726,7 +1716,7 @@ class Brain_Data(object):
                 name=img_name,
                 modality=img_modality,
                 map_type=img_type,
-                **kwargs
+                **kwargs,
             )
 
         if len(self.shape()) == 1:
@@ -1786,7 +1776,7 @@ class Brain_Data(object):
             standardize=standardize,
             high_pass=high_pass,
             low_pass=low_pass,
-            **kwargs
+            **kwargs,
         )
         return out
 
@@ -1955,23 +1945,25 @@ class Brain_Data(object):
         n_jobs=-1,
         random_state=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
-        """Bootstrap a Brain_Data method.
-
-            Example Useage:
-            b = dat.bootstrap('mean', n_samples=5000)
-            b = dat.bootstrap('predict', n_samples=5000, algorithm='ridge')
-            b = dat.bootstrap('predict', n_samples=5000, save_weights=True)
+        """Bootstrap a `Brain_Data` method.
 
         Args:
             function: (str) method to apply to data for each bootstrap
             n_samples: (int) number of samples to bootstrap with replacement
-            save_weights: (bool) Save each bootstrap iteration
-                        (useful for aggregating many bootstraps on a cluster)
-            n_jobs: (int) The number of CPUs to use to do the computation.
-                        -1 means all CPUs.Returns:
-        output: summarized studentized bootstrap output
+            save_weights: (bool) Save each bootstrap iteration (useful for aggregating
+            many bootstraps on a cluster)
+            n_jobs: (int) The number of CPUs to use to do the computation. -1 means all
+            CPUs.Returns:
+
+        Returns:
+            output: summarized studentized bootstrap output
+
+        Examples:
+            >>>  b = dat.bootstrap('mean', n_samples=5000)
+            >>>  b = dat.bootstrap('predict', n_samples=5000, algorithm='ridge')
+            >>>  b = dat.bootstrap('predict', n_samples=5000, save_weights=True)
 
         """
 
@@ -2036,16 +2028,6 @@ class Brain_Data(object):
 
         See nltools.stats.align for aligning multiple Brain_Data instances
 
-        Examples:
-            Hyperalign using procrustes transform:
-                out = data.align(target, method='procrustes')
-
-            Align using shared response model:
-                out = data.align(target, method='probabilistic_srm', n_features=None)
-
-            Project aligned data into original data:
-                original_data = np.dot(out['transformed'].data,out['transformation_matrix'].T)
-
         Args:
             target: (Brain_Data) object to align to.
             method: (str) alignment method to use
@@ -2056,6 +2038,13 @@ class Brain_Data(object):
             out: (dict) a dictionary containing transformed object,
                 transformation matrix, and the shared response matrix
 
+        Examples:
+            - Hyperalign using procrustes transform:
+                >>> out = data.align(target, method='procrustes')
+            - Align using shared response model:
+                >>> out = data.align(target, method='probabilistic_srm', n_features=None)
+            - Project aligned data into original data:
+                >>> original_data = np.dot(out[‘transformed’].data,out[‘transformation_matrix’].T)
         """
 
         if method not in ["probabilistic_srm", "deterministic_srm", "procrustes"]:
@@ -2156,19 +2145,20 @@ class Brain_Data(object):
         )
 
     def temporal_resample(self, sampling_freq=None, target=None, target_type="hz"):
-        """Resample Brain_Data timeseries to a new target frequency or number of samples
+        """
+        Resample Brain_Data timeseries to a new target frequency or number of samples
         using Piecewise Cubic Hermite Interpolating Polynomial (PCHIP) interpolation.
         This function can up- or down-sample data.
 
         Note: this function can use quite a bit of RAM.
 
-            Args:
-                sampling_freq:  (float) sampling frequency of data in hertz
-                target: (float) upsampling target
-                target_type: (str) type of target can be [samples,seconds,hz]
+        Args:
+            sampling_freq:  (float) sampling frequency of data in hertz
+            target: (float) upsampling target
+            target_type: (str) type of target can be [samples,seconds,hz]
 
-            Returns:
-                upsampled Brain_Data instance
+        Returns:
+            upsampled Brain_Data instance
         """
 
         out = self.copy()
