@@ -225,7 +225,7 @@ def multi_threshold(t_map, p_map, thresh):
     if not isinstance(thresh, list):
         raise ValueError("Make sure thresh is a list of p-values")
 
-    affine = t_map.to_nifti().get_affine()
+    affine = t_map.to_nifti().affine
     pos_out = np.zeros(t_map.to_nifti().shape)
     neg_out = deepcopy(pos_out)
     for thr in thresh:
@@ -812,9 +812,9 @@ def transform_pairwise(X, y):
     there are the same number of -1 as +1
 
     Reference: "Large Margin Rank Boundaries for Ordinal Regression",
-    R. Herbrich, T. Graepel, K. Obermayer.
-    Authors: Fabian Pedregosa <fabian@fseoane.net>
-             Alexandre Gramfort <alexandre.gramfort@inria.fr>
+    R. Herbrich, T. Graepel, K. Obermayer. Authors: Fabian Pedregosa
+    <fabian@fseoane.net> Alexandre Gramfort <alexandre.gramfort@inria.fr>
+
     Args:
         X: (np.array), shape (n_samples, n_features)
             The data
@@ -888,18 +888,18 @@ def _robust_estimator(vals, X, robust_estimator="hc0", nlags=1):
 
     # Then we need meat
     if robust_estimator == "hc0":
-        V = np.diag(vals ** 2)
+        V = np.diag(vals**2)
         meat = np.dot(np.dot(X.T, V), X)
 
     elif robust_estimator == "hc3":
-        V = np.diag(vals ** 2) / (1 - np.diag(np.dot(X, np.dot(bread, X.T)))) ** 2
+        V = np.diag(vals**2) / (1 - np.diag(np.dot(X, np.dot(bread, X.T)))) ** 2
         meat = np.dot(np.dot(X.T, V), X)
 
     elif robust_estimator == "hac":
         weights = 1 - np.arange(nlags + 1.0) / (nlags + 1.0)
 
         # First compute lag 0
-        V = np.diag(vals ** 2)
+        V = np.diag(vals**2)
         meat = weights[0] * np.dot(np.dot(X.T, V), X)
 
         # Now loop over additional lags
@@ -996,12 +996,38 @@ def regress(X, Y, mode="ols", stats="full", **kwargs):
     Does NOT add an intercept automatically to the X matrix before fitting like some other software packages. This is left up to the user.
 
     This function can compute regression in 3 ways:
-    1) Standard OLS
-    2) OLS with robust sandwich estimators for standard errors. 3 robust types of estimators exist:
-        1) 'hc0' - classic huber-white estimator robust to heteroscedasticity (default)
-        2) 'hc3' - a variant on huber-white estimator slightly more conservative when sample sizes are small
-        3) 'hac' - an estimator robust to both heteroscedasticity and auto-correlation; auto-correlation lag can be controlled with the 'nlags' keyword argument; default is 1
-    3) ARMA (auto-regressive moving-average) model (experimental). This model is fit through statsmodels.tsa.arima_model.ARMA, so more information about options can be found there. Any settings can be passed in as kwargs. By default fits a (1,1) model with starting lags of 2. This mode is **computationally intensive** and can take quite a while if Y has many columns.  If Y is a 2d array joblib.Parallel is used for faster fitting by parallelizing fits across columns of Y. Parallelization can be controlled by passing in kwargs. Defaults to multi-threading using 10 separate threads, as threads don't require large arrays to be duplicated in memory. Defaults are also set to enable memory-mapping for very large arrays if backend='multiprocessing' to prevent crashes and hangs. Various levels of progress can be monitored using the 'disp' (statsmodels) and 'verbose' (joblib) keyword arguments with integer values > 0.
+
+    1. Standard OLS
+    2. OLS with robust sandwich estimators for standard errors. 3 robust types of
+       estimators exist:
+
+    - 'hc0' - classic huber-white estimator robust to heteroscedasticity (default)
+    - 'hc3' - a variant on huber-white estimator slightly more conservative when sample sizes are small
+    - 'hac' - an estimator robust to both heteroscedasticity and auto-correlation;
+      auto-correlation lag can be controlled with the `nlags` keyword argument; default
+      is 1
+
+    3. ARMA (auto-regressive moving-average) model (experimental). This model is fit through statsmodels.tsa.arima_model.ARMA, so more information about options can be found there. Any settings can be passed in as kwargs. By default fits a (1,1) model with starting lags of 2. This mode is **computationally intensive** and can take quite a while if Y has many columns.  If Y is a 2d array joblib.Parallel is used for faster fitting by parallelizing fits across columns of Y. Parallelization can be controlled by passing in kwargs. Defaults to multi-threading using 10 separate threads, as threads don't require large arrays to be duplicated in memory. Defaults are also set to enable memory-mapping for very large arrays if backend='multiprocessing' to prevent crashes and hangs. Various levels of progress can be monitored using the 'disp' (statsmodels) and 'verbose' (joblib) keyword arguments with integer values > 0.
+
+    Args:
+        X (ndarray): design matrix; assumes intercept is included
+        Y (ndarray): dependent variable array; if 2d, a model is fit to each column of Y separately
+        mode (str): kind of model to fit; must be one of 'ols' (default), 'robust', or
+        'arma'
+        stats (str): one of 'full', 'betas', 'tstats'. Useful to speed up calculation if
+        you know you only need some statistics and not others. Defaults to 'full'.
+        robust_estimator (str,optional): kind of robust estimator to use if mode = 'robust'; default 'hc0'
+        nlags (int,optional): auto-correlation lag correction if mode = 'robust' and robust_estimator = 'hac'; default 1
+        order (tuple,optional): auto-regressive and moving-average orders for mode = 'arma'; default (1,1)
+        kwargs (dict): additional keyword arguments to statsmodels.tsa.arima_model.ARMA and joblib.Parallel
+
+    Returns:
+        b: coefficients
+        se: standard error of coefficients
+        t: t-statistics (coef/sterr)
+        p : p-values
+        df: degrees of freedom
+        res: residuals
 
     Examples:
         Standard OLS
@@ -1024,22 +1050,6 @@ def regress(X, Y, mode="ols", stats="full", **kwargs):
 
         >>> results = regress(X,Y,mode='arma',order=(2,3),backend='multiprocessing',n_jobs=8)
 
-    Args:
-        X (ndarray): design matrix; assumes intercept is included
-        Y (ndarray): dependent variable array; if 2d, a model is fit to each column of Y separately
-        mode (str): kind of model to fit; must be one of 'ols' (default), 'robust', or 'arma'
-        robust_estimator (str,optional): kind of robust estimator to use if mode = 'robust'; default 'hc0'
-        nlags (int,optional): auto-correlation lag correction if mode = 'robust' and robust_estimator = 'hac'; default 1
-        order (tuple,optional): auto-regressive and moving-average orders for mode = 'arma'; default (1,1)
-        kwargs (dict): additional keyword arguments to statsmodels.tsa.arima_model.ARMA and joblib.Parallel
-
-    Returns:
-        b: coefficients
-        t: t-statistics (coef/sterr)
-        p : p-values
-        df: degrees of freedom
-        res: residuals
-
     """
 
     if not isinstance(mode, str):
@@ -1124,7 +1134,18 @@ def regress(X, Y, mode="ols", stats="full", **kwargs):
         else:
             b, t, p, df, res = _arma_func(X, Y, **kwargs)
 
-    return b.squeeze(), t.squeeze(), p.squeeze(), df.squeeze(), res.squeeze()
+        # Arma models don't return stderr, so make a variable for consistent function
+        # return values
+        stderr = np.empty_like(b)
+
+    return (
+        b.squeeze(),
+        stderr.squeeze(),
+        t.squeeze(),
+        p.squeeze(),
+        df.squeeze(),
+        res.squeeze(),
+    )
 
 
 def regress_permutation(
@@ -1192,15 +1213,6 @@ def align(data, method="deterministic_srm", n_features=None, axis=0, *args, **kw
     original data using Tranformation matrix. Inputs must be a list of Brain_Data
     instances or numpy arrays (observations by features).
 
-    Examples:
-        Hyperalign using procrustes transform:
-            out = align(data, method='procrustes')
-
-        Align using shared response model:
-            out = align(data, method='probabilistic_srm', n_features=None)
-
-        Project aligned data into original data:
-            original_data = [np.dot(t.data,tm.T) for t,tm in zip(out['transformed'], out['transformation_matrix'])]
 
     Args:
         data: (list) A list of Brain_Data objects
@@ -1215,6 +1227,13 @@ def align(data, method="deterministic_srm", n_features=None, axis=0, *args, **kw
             matrices, a list of transformation matrices, the shared
             response matrix, and the intersubject correlation of the shared resposnes
 
+    Examples:
+        - Hyperalign using procrustes transform:
+            >>> out = align(data, method='procrustes')
+        - Align using shared response model:
+            >>> out = align(data, method='probabilistic_srm', n_features=None)
+        - Project aligned data into original data:
+            >>> original_data = [np.dot(t.data,tm.T) for t,tm in zip(out['transformed'], out['transformation_matrix'])]
     """
 
     from nltools.data import Brain_Data, Adjacency
@@ -1572,7 +1591,7 @@ def distance_correlation(x, y, bias_corrected=True, ttest=False):
         out["dcorr_squared"] = dcor
     if ttest:
         dof = (adjusted_n / 2) - 1
-        t = np.sqrt(dof) * (dcor / np.sqrt(1 - dcor ** 2))
+        t = np.sqrt(dof) * (dcor / np.sqrt(1 - dcor**2))
         p = 1 - t_dist.cdf(t, dof)
         out["t"] = t
         out["p"] = p
@@ -2192,8 +2211,8 @@ def _phase_rayleigh_p(phase_angles):
     if n <= 50:
         return np.exp(-1 * Z) * (
             1
-            + (2 * Z - Z ** 2) / (4 * n)
-            - (24 * Z - 132 * Z ** 2 + 76 * Z ** 3 - 9 * Z ** 4) / (288 * n ** 2)
+            + (2 * Z - Z**2) / (4 * n)
+            - (24 * Z - 132 * Z**2 + 76 * Z**3 - 9 * Z**4) / (288 * n**2)
         )
     else:
         return np.exp(-1 * Z)
